// content.js
(function() {
  'use strict';

  // Function to inject code into the page context
  const injectScript = (func) => {
    const script = document.createElement('script');
    script.textContent = `(${func.toString()})();`;
    (document.head || document.documentElement).appendChild(script);
    script.remove();
  };

  // Code to be injected into the page context
  const pageScript = () => {
    // Store the original ytInitialPlayerResponse getter
    const originalGetter = Object.getOwnPropertyDescriptor(window, 'ytInitialPlayerResponse');
    
    // Override ytInitialPlayerResponse to modify loop setting
    Object.defineProperty(window, 'ytInitialPlayerResponse', {
      get: function() {
        const response = originalGetter.get.call(this);
        if (response && location.pathname.startsWith('/shorts/')) {
          // Ensure playback settings exist and set loop to false
          if (!response.playbackConfig) {
            response.playbackConfig = {};
          }
          response.playbackConfig.loopVideo = false;
        }
        return response;
      },
      configurable: true
    });

    // Also watch for navigation events
    const handleNavigation = () => {
      if (location.pathname.startsWith('/shorts/')) {
        // Find and modify any video elements
        document.querySelectorAll('video').forEach(video => {
          video.loop = false;
          console.log('Loop disabled via navigation handler');
        });

        // Also try to modify the player response if it exists
        if (window.ytInitialPlayerResponse) {
          if (!window.ytInitialPlayerResponse.playbackConfig) {
            window.ytInitialPlayerResponse.playbackConfig = {};
          }
          window.ytInitialPlayerResponse.playbackConfig.loopVideo = false;
        }
      }
    };

    // Listen for YouTube's own navigation events
    document.addEventListener('yt-navigate-start', handleNavigation);
    document.addEventListener('yt-navigate-finish', handleNavigation);
  };

  // Inject our page script
  injectScript(pageScript);

  // Backup method in content script context
  const disableLoop = () => {
    if (!location.pathname.startsWith('/shorts/')) return;
    
    document.querySelectorAll('video').forEach(video => {
      if (video.loop) {
        video.loop = false;
        console.log('Loop disabled via content script');
      }
    });
  };

  // Run periodic checks as backup
  setInterval(disableLoop, 100);

  // Watch for URL changes in content script context
  let lastUrl = location.href;
  new MutationObserver(() => {
    if (location.href !== lastUrl) {
      lastUrl = location.href;
      if (location.pathname.startsWith('/shorts/')) {
        setTimeout(disableLoop, 0);
        setTimeout(disableLoop, 500);
      }
    }
  }).observe(document, { subtree: true, childList: true });

  // Initial check
  if (document.readyState === 'loading') {
    document.addEventListener('DOMContentLoaded', disableLoop);
  } else {
    disableLoop();
  }
})();
